DAG Visualization

### エッジ編集

エッジを選択してください

エッジ:

ラベル:

新しい接続先:

### 追加: ノード

ノードID (必須):
ノードタイプ:
説明 (任意):

### 追加: エッジ

接続元ノード:
接続先ノード:
ラベル (状態名):

### 統合: 選択ノード

Ctrl+クリックで複数ノードを選択してください

選択中のノード:
まとめ後の表示名:

### 統合: プレフィックス指定

指定したプレフィックスを持つノードを統合します

親プレフィックス:
まとめ後の表示名:
対象ノード (プレビュー):

### 統合: グループ内

表示グループ内のノードを統合します

まとめるグループ:
対象ノード:

### 色: 設定

選択中の要素に色を設定します

選択中:
背景色:
枠線:
文字の縁:
文字色:
カラーパレット (クリックで背景色に適用):

### グループ: 作成

選択中のノードで新しいグループを作成します

選択中のノード:
グループ名:
グループ色:
#9C27B0

### グループ: ノード追加

選択中のノードを既存グループに追加します

選択中のノード:
追加先グループ:

### ノード情報

ID:

説明: